@@ -43,7 +43,12 @@ sub _AUTO : Private {
 
 sub _ACTION : Private {
     my ( $self, $c ) = @_;
-    $c->action->execute($c);
+    if (   ref $c->action
+        && $c->action->isa('Catalyst::Action')
+        && $c->req->action )
+    {
+        $c->action->execute($c);
+    }
     return !@{ $c->error };
 }
 
